==> haskell-tuple-th-0.2.5-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tuple-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tuple-th
version:              0.2.5
visibility:           public
id:                   tuple-th-0.2.5-JUMtLoKj6GPEXFZlvQmr3H
key:                  tuple-th-0.2.5-JUMtLoKj6GPEXFZlvQmr3H
license:              BSD-3-Clause
maintainer:           anotheraddress@gmx.de
author:               Daniel Schüssler
synopsis:
    Generate (non-recursive) utility functions for tuples of statically known size

description:
    Template Haskell functions for generating functions similar to those in Data.List for tuples of statically known size.

category:             Template Haskell, Data
abi:                  98382c189b465108fb4eeabe78c0301b
exposed:              True
exposed-modules:      TupleTH
import-dirs:          /usr/lib/ghc-8.8.3/site-local/tuple-th-0.2.5
library-dirs:         /usr/lib/ghc-8.8.3/site-local/tuple-th-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/tuple-th-0.2.5
hs-libraries:         HStuple-th-0.2.5-JUMtLoKj6GPEXFZlvQmr3H
depends:
    base-4.13.0.0 containers-0.6.2.1 template-haskell-2.15.0.0

haddock-interfaces:   /usr/share/doc/haskell-tuple-th/html/tuple-th.haddock
haddock-html:         /usr/share/doc/haskell-tuple-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tuple-th-0.2.5-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tuple-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tuple-th
version:              0.2.5
visibility:           public
id:                   tuple-th-0.2.5-4dMe7XGOpnoGOwshxxkayg
key:                  tuple-th-0.2.5-4dMe7XGOpnoGOwshxxkayg
license:              BSD-3-Clause
maintainer:           anotheraddress@gmx.de
author:               Daniel Schüssler
synopsis:
    Generate (non-recursive) utility functions for tuples of statically known size

description:
    Template Haskell functions for generating functions similar to those in Data.List for tuples of statically known size.

category:             Template Haskell, Data
abi:                  08f9abf55f3c201b1707befbca6b76e5
exposed:              True
exposed-modules:      TupleTH
import-dirs:          /usr/lib/ghc-8.10.1/site-local/tuple-th-0.2.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/tuple-th-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/tuple-th-0.2.5
hs-libraries:         HStuple-th-0.2.5-4dMe7XGOpnoGOwshxxkayg
depends:
    base-4.14.0.0 containers-0.6.2.1 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-tuple-th/html/tuple-th.haddock
haddock-html:         /usr/share/doc/haskell-tuple-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
